@@ -1,9 +1,9 @@
 #' A future with a constant value
 #'
 #' A constant future is a future whose expression is a constant
-#' and therefore already resolved upon creation
+#' and therefore by definition already resolved upon creation.
 #'
-#' @param expr An R value.
+#' @inheritParams Future-class
 #' @param \dots Not used.
 #'
 #' @return An object of class \code{ConstantFuture}.
@@ -11,13 +11,11 @@
 #' @export
 #' @name ConstantFuture-class
 #' @keywords internal
-ConstantFuture <- function(expr=NULL, envir=emptyenv(), substitute=FALSE, local=FALSE, gc=FALSE, ...) {
+ConstantFuture <- function(expr=NULL, envir=emptyenv(), substitute=FALSE, local=FALSE, ...) {
   expr <- force(expr)
-  f <- Future(expr=expr, envir=emptyenv(), substitute=FALSE, local=FALSE, gc=FALSE, ...)
+  f <- Future(expr=expr, envir=emptyenv(), substitute=FALSE, local=FALSE, ...)
   f$value <- expr
   f$state <- "finished"
   structure(f, class=c("ConstantFuture", class(f)))
   f
 }
-
-evaluate.ConstantFuture <- function(future, ...) future
