@@ -1,7 +1,4 @@
-library("future")
-
-ovars <- ls()
-oopts <- options(warn=1L, mc.cores=2L, future.debug=TRUE)
+source("incl/start.R")
 
 message("*** backtrace( ) ...")
 
@@ -55,8 +52,4 @@ message("*** backtrace( ) - exceptions ... DONE")
 
 message("*** backtrace( ) ... DONE")
 
-
-## Cleanup
-plan(eager)
-options(oopts)
-rm(list=setdiff(ls(), ovars))
+source("incl/end.R")
