@@ -1,8 +1,6 @@
-library("future")
-
-ovars <- ls()
-oopts <- options(warn=1L, mc.cores=2L, future.debug=TRUE)
+source("incl/start.R")
 
+options(future.debug=FALSE)
 
 message("*** Early signaling of conditions ...")
 
@@ -10,6 +8,7 @@ message("*** Early signaling of conditions with eager futures ...")
 
 plan(eager)
 f <- future({ stop("bang!") })
+Sys.sleep(1.0)
 r <- resolved(f)
 stopifnot(r)
 v <- try(value(f), silent=TRUE)
@@ -26,6 +25,7 @@ message("*** Early signaling of conditions with lazy futures ...")
 
 plan(lazy)
 f <- future({ stop("bang!") })
+Sys.sleep(1.0)
 r <- resolved(f)
 stopifnot(r)
 v <- try(value(f), silent=TRUE)
@@ -35,6 +35,7 @@ plan(lazy, earlySignal=TRUE)
 
 ## Errors
 f <- future({ stop("bang!") })
+Sys.sleep(1.0)
 r <- try(resolved(f), silent=TRUE)
 stopifnot(inherits(r, "try-error"))
 v <- try(value(f), silent=TRUE)
@@ -42,6 +43,7 @@ stopifnot(inherits(v, "try-error"))
 
 ## Warnings
 f <- future({ warning("careful!") })
+Sys.sleep(1.0)
 res <- tryCatch({
   r <- resolved(f)
 }, condition = function(w) w)
@@ -49,6 +51,7 @@ stopifnot(inherits(res, "warning"))
 
 ## Messages
 f <- future({ message("hey!") })
+Sys.sleep(1.0)
 res <- tryCatch({
   r <- resolved(f)
 }, condition = function(w) w)
@@ -56,6 +59,7 @@ stopifnot(inherits(res, "message"))
 
 ## Condition
 f <- future({ signalCondition(simpleCondition("hmm")) })
+Sys.sleep(1.0)
 res <- tryCatch({
   r <- resolved(f)
 }, condition = function(w) w)
@@ -69,6 +73,7 @@ message("*** Early signaling of conditions with multisession futures ...")
 
 plan(multisession)
 f <- future({ stop("bang!") })
+Sys.sleep(1.0)
 r <- resolved(f)
 stopifnot(r)
 v <- try(value(f), silent=TRUE)
@@ -76,6 +81,7 @@ stopifnot(inherits(v, "try-error"))
 
 plan(multisession, earlySignal=TRUE)
 f <- future({ stop("bang!") })
+Sys.sleep(1.0)
 print(f)
 r <- try(resolved(f), silent=TRUE)
 stopifnot(inherits(r, "try-error") || inherits(f, "UniprocessFuture"))
@@ -90,6 +96,7 @@ message("*** Early signaling of conditions with multiprocess futures ...")
 
 plan(multiprocess)
 f <- future({ stop("bang!") })
+Sys.sleep(1.0)
 r <- resolved(f)
 stopifnot(r)
 v <- try(value(f), silent=TRUE)
@@ -97,6 +104,7 @@ stopifnot(inherits(v, "try-error"))
 
 plan(multiprocess, earlySignal=TRUE)
 f <- future({ stop("bang!") })
+Sys.sleep(1.0)
 print(f)
 r <- try(resolved(f), silent=TRUE)
 stopifnot(inherits(r, "try-error") || inherits(f, "UniprocessFuture"))
@@ -105,9 +113,6 @@ stopifnot(inherits(v, "try-error"))
 
 message("*** Early signaling of conditions with multiprocess futures ... DONE")
 
-
 message("*** Early signaling of conditions ... DONE")
 
-plan(eager)
-options(oopts)
-rm(list=setdiff(ls(), ovars))
+source("incl/end.R")
